@@ -255,7 +255,7 @@ void startGenerateKeysProcess(QProcess *process, bool useTransientPasswordlessKe
     startGpgProcess(process, args, QIODevice::ReadWrite);
     process->write( "\nKey-Type: RSA"
              "\nKey-Usage: encrypt"
-             "\nKey-Length: 2048"
+             "\nKey-Length: 4096"
              "\nName-Real: copyq"
              + transientOptions +
              "\n%secring " + keys.sec.toUtf8() +
@@ -296,9 +296,6 @@ ItemEncrypted::ItemEncrypted(QWidget *parent)
 bool ItemEncryptedSaver::saveItems(const QString &, const QAbstractItemModel &model, QIODevice *file)
 {
     const auto length = model.rowCount();
-    if (length == 0)
-        return false; // No need to encode empty tab.
-
     QByteArray bytes;
 
     {
@@ -720,7 +717,7 @@ ItemSaverPtr ItemEncryptedLoader::loadItems(const QString &, QAbstractItemModel
 
     quint64 length;
     stream2 >> length;
-    if ( length <= 0 || stream2.status() != QDataStream::Ok ) {
+    if ( stream2.status() != QDataStream::Ok ) {
         emitDecryptFailed();
         COPYQ_LOG("ItemEncrypt ERROR: Failed to parse item count!");
         return nullptr;
