@@ -1,21 +1,4 @@
-/*
-    Copyright (c) 2020, Lukas Holecek <hluk@email.cz>
-
-    This file is part of CopyQ.
-
-    CopyQ is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    CopyQ is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with CopyQ.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "itemsynctests.h"
 
@@ -748,3 +731,23 @@ void ItemSyncTests::moveOwnItemsSortsBaseNames()
     RUN(args << "read(0,1,2,3)", "B,C,D,A");
     RUN(args << testScript, "");
 }
+
+void ItemSyncTests::avoidDuplicateItemsAddedFromClipboard()
+{
+    TestDir dir1(1);
+    const QString tab1 = testTab(1);
+    RUN("show" << tab1, "");
+
+    const Args args = Args() << "separator" << "," << "tab" << tab1;
+
+    RUN("config" << "clipboard_tab" << tab1, tab1 + "\n");
+
+    TEST( m_test->setClipboard("one") );
+    WAIT_ON_OUTPUT(args << "read(0,1,2,3)", "one,,,");
+
+    TEST( m_test->setClipboard("two") );
+    WAIT_ON_OUTPUT(args << "read(0,1,2,3)", "two,one,,");
+
+    TEST( m_test->setClipboard("one") );
+    WAIT_ON_OUTPUT(args << "read(0,1,2,3)", "one,two,,");
+}
