@@ -87,23 +87,23 @@ void registerMetaTypes() {
     qRegisterMetaTypeStreamOperators<ClipboardMode>("ClipboardMode");
     qRegisterMetaTypeStreamOperators<Command>("Command");
     qRegisterMetaTypeStreamOperators<NamedValueList>("NamedValueList");
-    qRegisterMetaTypeStreamOperators<NotificationButtons>("NotificationButtons");
+    qRegisterMetaTypeStreamOperators<NotificationButtonList>("NotificationButtonList");
     qRegisterMetaTypeStreamOperators<ScriptablePath>("ScriptablePath");
     qRegisterMetaTypeStreamOperators<QVector<int>>("QVector<int>");
     qRegisterMetaTypeStreamOperators<QVector<Command>>("QVector<Command>");
-    qRegisterMetaTypeStreamOperators<QVector<QVariantMap>>("QVector<QVariantMap>");
-    qRegisterMetaTypeStreamOperators<Qt::KeyboardModifiers>("Qt::KeyboardModifiers");
+    qRegisterMetaTypeStreamOperators<VariantMapList>("VariantMapList");
+    qRegisterMetaTypeStreamOperators<KeyboardModifierList>("KeyboardModifierList");
 #else
     qRegisterMetaType<QPointer<QWidget>>("QPointer<QWidget>");
     qRegisterMetaType<ClipboardMode>("ClipboardMode");
     qRegisterMetaType<Command>("Command");
     qRegisterMetaType<NamedValueList>("NamedValueList");
-    qRegisterMetaType<NotificationButtons>("NotificationButtons");
+    qRegisterMetaType<NotificationButtonList>("NotificationButtonList");
     qRegisterMetaType<ScriptablePath>("ScriptablePath");
     qRegisterMetaType<QVector<int>>("QVector<int>");
     qRegisterMetaType<QVector<Command>>("QVector<Command>");
-    qRegisterMetaType<QVector<QVariantMap>>("QVector<QVariantMap>");
-    qRegisterMetaType<Qt::KeyboardModifiers>("Qt::KeyboardModifiers");
+    qRegisterMetaType<VariantMapList>("VariantMapList");
+    qRegisterMetaType<KeyboardModifierList>("KeyboardModifierList");
 #endif
 
     registered = true;
@@ -183,28 +183,33 @@ void selectionRemoveInvalid(QList<QPersistentModelIndex> *indexes)
 
 Q_DECLARE_METATYPE(QFile*)
 
-QDataStream &operator<<(QDataStream &out, const NotificationButton &button)
+QDataStream &operator<<(QDataStream &out, const NotificationButtonList &list)
 {
-    out << button.name
-        << button.script
-        << button.data;
+    out << list.items.size();
+    for (const auto &button : list.items)
+        out << button.name << button.script << button.data;
     Q_ASSERT(out.status() == QDataStream::Ok);
     return out;
 }
 
-QDataStream &operator>>(QDataStream &in, NotificationButton &button)
+QDataStream &operator>>(QDataStream &in, NotificationButtonList &list)
 {
-    in >> button.name
-       >> button.script
-       >> button.data;
+    decltype(list.items.size()) size;
+    in >> size;
+    list.items.reserve(size);
+    for (int i = 0; i < size; ++i) {
+        NotificationButton button;
+        in >> button.name >> button.script >> button.data;
+        list.items.append(button);
+    }
     Q_ASSERT(in.status() == QDataStream::Ok);
     return in;
 }
 
 QDataStream &operator<<(QDataStream &out, const NamedValueList &list)
 {
-    out << list.size();
-    for (const auto &item : list)
+    out << list.items.size();
+    for (const auto &item : list.items)
         out << item.name << item.value;
     Q_ASSERT(out.status() == QDataStream::Ok);
     return out;
@@ -212,17 +217,32 @@ QDataStream &operator<<(QDataStream &out, const NamedValueList &list)
 
 QDataStream &operator>>(QDataStream &in, NamedValueList &list)
 {
-    int size;
+    decltype(list.items.size()) size;
     in >> size;
+    list.items.reserve(size);
     for (int i = 0; i < size; ++i) {
         NamedValue item;
         in >> item.name >> item.value;
-        list.append(item);
+        list.items.append(item);
     }
     Q_ASSERT(in.status() == QDataStream::Ok);
     return in;
 }
 
+QDataStream &operator<<(QDataStream &out, const VariantMapList &items)
+{
+    out << items.items;
+    Q_ASSERT(out.status() == QDataStream::Ok);
+    return out;
+}
+
+QDataStream &operator>>(QDataStream &in, VariantMapList &items)
+{
+    in >> items.items;
+    Q_ASSERT(in.status() == QDataStream::Ok);
+    return in;
+}
+
 QDataStream &operator<<(QDataStream &out, ClipboardMode mode)
 {
     const int modeId = static_cast<int>(mode);
@@ -250,17 +270,17 @@ QDataStream &operator>>(QDataStream &in, ScriptablePath &path)
     return in >> path.path;
 }
 
-QDataStream &operator<<(QDataStream &out, Qt::KeyboardModifiers value)
+QDataStream &operator<<(QDataStream &out, KeyboardModifierList value)
 {
-    return out << static_cast<int>(value);
+    return out << static_cast<int>(value.items);
 }
 
-QDataStream &operator>>(QDataStream &in, Qt::KeyboardModifiers &value)
+QDataStream &operator>>(QDataStream &in, KeyboardModifierList &value)
 {
     int valueInt;
     in >> valueInt;
     Q_ASSERT(in.status() == QDataStream::Ok);
-    value = static_cast<Qt::KeyboardModifiers>(valueInt);
+    value.items = static_cast<Qt::KeyboardModifiers>(valueInt);
     return in;
 }
 
@@ -921,7 +941,7 @@ QByteArray ScriptableProxy::callFunctionHelper(const QByteArray &serializedFunct
         auto &value = arguments[i];
         const int argumentTypeId = metaMethod.parameterType(i);
         if (argumentTypeId == QMetaType::QVariant) {
-            args[i] = Q_ARG(QVariant, value);
+            args[i] = QGenericArgument( "QVariant", static_cast<void*>(value.data()) );
         } else if ( value.userType() == argumentTypeId ) {
             args[i] = QGenericArgument( value.typeName(), static_cast<void*>(value.data()) );
         } else {
@@ -949,8 +969,8 @@ QByteArray ScriptableProxy::callFunctionHelper(const QByteArray &serializedFunct
         returnValue = QVariant(typeId, nullptr);
 #endif
         const auto genericReturnValue = returnValue.isValid()
-                ? QGenericReturnArgument(returnValue.typeName(), static_cast<void*>(returnValue.data()) )
-                : Q_RETURN_ARG(QVariant, returnValue);
+                ? QGenericReturnArgument( returnValue.typeName(), static_cast<void*>(returnValue.data()) )
+                : QGenericReturnArgument( "QVariant", static_cast<void*>(returnValue.data()) );
 
         called = metaMethod.invoke(
                 this, genericReturnValue,
@@ -1262,7 +1282,7 @@ void ScriptableProxy::showMessage(const QString &title,
         const QString &icon,
         int msec,
         const QString &notificationId,
-        const NotificationButtons &buttons)
+        const NotificationButtonList &buttons)
 {
     INVOKE2(showMessage, (title, msg, icon, msec, notificationId, buttons));
 
@@ -1271,7 +1291,7 @@ void ScriptableProxy::showMessage(const QString &title,
     notification->setMessage(msg, Qt::AutoText);
     notification->setIcon(icon);
     notification->setInterval(msec);
-    notification->setButtons(buttons);
+    notification->setButtons(buttons.items);
 }
 
 QVariantMap ScriptableProxy::nextItem(const QString &tabName, int where)
@@ -1391,7 +1411,7 @@ int ScriptableProxy::findTabIndex(const QString &arg1)
     return m_wnd->findTabIndex(arg1);
 }
 
-int ScriptableProxy::menuItems(const QVector<QVariantMap> &items)
+int ScriptableProxy::menuItems(const VariantMapList &items)
 {
     INVOKE(menuItems, (items));
 
@@ -1401,7 +1421,7 @@ int ScriptableProxy::menuItems(const QVector<QVariantMap> &items)
 
     const auto addMenuItems = [&](const QString &searchText) {
         menu.clearClipboardItems();
-        for (const QVariantMap &data : items) {
+        for (const QVariantMap &data : items.items) {
             const QString text = getTextData(data);
             if ( text.contains(searchText, Qt::CaseInsensitive) )
                 menu.addClipboardItemAction(data, true);
@@ -1416,7 +1436,7 @@ int ScriptableProxy::menuItems(const QVector<QVariantMap> &items)
     if (act == nullptr)
         return -1;
 
-    return items.indexOf(act->data().toMap());
+    return items.items.indexOf(act->data().toMap());
 }
 
 void ScriptableProxy::openActionDialog(const QVariantMap &arg1)
@@ -1499,7 +1519,7 @@ bool ScriptableProxy::browserOpenEditor(const QString &tabName, const QByteArray
     return c && c->openEditor(arg1, changeClipboard);
 }
 
-QString ScriptableProxy::browserInsert(const QString &tabName, int row, const QVector<QVariantMap> &items)
+QString ScriptableProxy::browserInsert(const QString &tabName, int row, const VariantMapList &items)
 {
     INVOKE(browserInsert, (tabName, row, items));
 
@@ -1507,10 +1527,10 @@ QString ScriptableProxy::browserInsert(const QString &tabName, int row, const QV
     if (!c)
         return QLatin1String("Invalid tab");
 
-    if ( !c->allocateSpaceForNewItems(items.size()) )
+    if ( !c->allocateSpaceForNewItems(items.items.size()) )
         return QLatin1String("Tab is full (cannot remove any items)");
 
-    for (const auto &item : items) {
+    for (const auto &item : items.items) {
         if ( !c->add(item, row) )
             return QLatin1String("Failed to new add items");
     }
@@ -1518,7 +1538,7 @@ QString ScriptableProxy::browserInsert(const QString &tabName, int row, const QV
     return QString();
 }
 
-QString ScriptableProxy::browserChange(const QString &tabName, int row, const QVector<QVariantMap> &items)
+QString ScriptableProxy::browserChange(const QString &tabName, int row, const VariantMapList &items)
 {
     INVOKE(browserChange, (tabName, row, items));
 
@@ -1527,7 +1547,7 @@ QString ScriptableProxy::browserChange(const QString &tabName, int row, const QV
         return QLatin1String("Invalid tab");
 
     int currentRow = row;
-    for (const auto &data : items) {
+    for (const auto &data : items.items) {
         const auto index = c->index(currentRow);
         QVariantMap itemData = c->model()->data(index, contentType::data).toMap();
         for (auto it = data.constBegin(); it != data.constEnd(); ++it) {
@@ -1643,13 +1663,13 @@ bool ScriptableProxy::setSelectedItemData(int selectedIndex, const QVariantMap &
     return c->model()->setData(index, data, contentType::data);
 }
 
-QVector<QVariantMap> ScriptableProxy::selectedItemsData()
+VariantMapList ScriptableProxy::selectedItemsData()
 {
     INVOKE(selectedItemsData, ());
 
     auto c = currentBrowser();
     if (!c)
-        return QVector<QVariantMap>();
+        return {};
 
     const auto model = c->model();
 
@@ -1664,10 +1684,10 @@ QVector<QVariantMap> ScriptableProxy::selectedItemsData()
         }
     }
 
-    return dataList;
+    return {dataList};
 }
 
-void ScriptableProxy::setSelectedItemsData(const QVector<QVariantMap> &dataList)
+void ScriptableProxy::setSelectedItemsData(const VariantMapList &dataList)
 {
     INVOKE2(setSelectedItemsData, (dataList));
 
@@ -1678,12 +1698,12 @@ void ScriptableProxy::setSelectedItemsData(const QVector<QVariantMap> &dataList)
     const auto model = c->model();
 
     const auto indexes = selectedIndexes();
-    const auto count = std::min( indexes.size(), dataList.size() );
+    const auto count = std::min( indexes.size(), dataList.items.size() );
     for ( int i = 0; i < count; ++i ) {
         const auto &index = indexes[i];
         if ( index.isValid() ) {
             Q_ASSERT( index.model() == model );
-            model->setData(index, dataList[i], contentType::data);
+            model->setData(index, dataList.items[i], contentType::data);
         }
     }
 }
@@ -2073,12 +2093,12 @@ int ScriptableProxy::inputDialog(const NamedValueList &values)
     QIcon icon;
     QVBoxLayout layout(&dialog);
     QWidgetList widgets;
-    widgets.reserve(values.size());
+    widgets.reserve(values.items.size());
 
     QString styleSheet;
     QRect geometry(-1, -1, 0, 0);
 
-    for (const auto &value : values) {
+    for (const auto &value : values.items) {
         if (value.name == ".title")
             dialogTitle = value.value.toString();
         else if (value.name == ".icon")
@@ -2134,14 +2154,14 @@ int ScriptableProxy::inputDialog(const NamedValueList &values)
             return;
 
         NamedValueList result;
-        result.reserve( widgets.size() );
+        result.items.reserve( widgets.size() );
 
         if ( inputDialog.dialog->result() ) {
             for ( auto w : widgets ) {
                 const QString propertyName = w->property(propertyWidgetProperty).toString();
                 const QString name = w->property(propertyWidgetName).toString();
                 const QVariant value = w->property(propertyName.toUtf8().constData());
-                result.append( NamedValue(name, value) );
+                result.items.append( NamedValue(name, value) );
             }
         }
 
@@ -2289,10 +2309,10 @@ QStringList ScriptableProxy::screenNames()
     return result;
 }
 
-Qt::KeyboardModifiers ScriptableProxy::queryKeyboardModifiers()
+KeyboardModifierList ScriptableProxy::queryKeyboardModifiers()
 {
     INVOKE(queryKeyboardModifiers, ());
-    return QApplication::queryKeyboardModifiers();
+    return {QApplication::queryKeyboardModifiers()};
 }
 
 QPoint ScriptableProxy::pointerPosition()
