@@ -33,7 +33,21 @@ struct NamedValue {
     QVariant value;
 };
 
-using NamedValueList = QVector<NamedValue>;
+struct VariantMapList {
+    QVector<QVariantMap> items;
+};
+
+struct NamedValueList {
+    QList<NamedValue> items;
+};
+
+struct NotificationButtonList {
+    QList<NotificationButton> items;
+};
+
+struct KeyboardModifierList {
+    Qt::KeyboardModifiers items;
+};
 
 struct ScriptablePath {
     QString path;
@@ -46,24 +60,26 @@ struct ItemSelection {
 
 Q_DECLARE_METATYPE(NamedValueList)
 Q_DECLARE_METATYPE(ScriptablePath)
-Q_DECLARE_METATYPE(NotificationButtons)
-Q_DECLARE_METATYPE(QVector<QVariantMap>)
-Q_DECLARE_METATYPE(Qt::KeyboardModifiers)
+Q_DECLARE_METATYPE(NotificationButtonList)
+Q_DECLARE_METATYPE(VariantMapList)
+Q_DECLARE_METATYPE(KeyboardModifierList)
 
 #if QT_VERSION < QT_VERSION_CHECK(6,0,0)
 Q_DECLARE_METATYPE(ClipboardMode)
 #endif
 
-QDataStream &operator<<(QDataStream &out, const NotificationButton &button);
-QDataStream &operator>>(QDataStream &in, NotificationButton &button);
+QDataStream &operator<<(QDataStream &out, const NotificationButtonList &list);
+QDataStream &operator>>(QDataStream &in, NotificationButtonList &list);
 QDataStream &operator<<(QDataStream &out, const NamedValueList &list);
 QDataStream &operator>>(QDataStream &in, NamedValueList &list);
+QDataStream &operator<<(QDataStream &out, const VariantMapList &list);
+QDataStream &operator>>(QDataStream &in, VariantMapList &list);
 QDataStream &operator<<(QDataStream &out, ClipboardMode mode);
 QDataStream &operator>>(QDataStream &in, ClipboardMode &mode);
 QDataStream &operator<<(QDataStream &out, const ScriptablePath &path);
 QDataStream &operator>>(QDataStream &in, ScriptablePath &path);
-QDataStream &operator<<(QDataStream &out, Qt::KeyboardModifiers value);
-QDataStream &operator>>(QDataStream &in, Qt::KeyboardModifiers &value);
+QDataStream &operator<<(QDataStream &out, KeyboardModifierList value);
+QDataStream &operator>>(QDataStream &in, KeyboardModifierList &value);
 
 class ScriptableProxy final : public QObject
 {
@@ -125,7 +141,7 @@ public slots:
             const QString &icon,
             int msec,
             const QString &notificationId = QString(),
-            const NotificationButtons &buttons = NotificationButtons());
+            const NotificationButtonList &buttons = NotificationButtonList());
 
     QVariantMap nextItem(const QString &tabName, int where);
     void browserMoveToClipboard(const QString &tabName, int row);
@@ -142,7 +158,7 @@ public slots:
     bool toggleCurrentMenu();
     int findTabIndex(const QString &arg1);
 
-    int menuItems(const QVector<QVariantMap> &items);
+    int menuItems(const VariantMapList &items);
 
     void openActionDialog(const QVariantMap &arg1);
 
@@ -159,8 +175,8 @@ public slots:
     int browserLength(const QString &tabName);
     bool browserOpenEditor(const QString &tabName, const QByteArray &arg1, bool changeClipboard);
 
-    QString browserInsert(const QString &tabName, int row, const QVector<QVariantMap> &items);
-    QString browserChange(const QString &tabName, int row, const QVector<QVariantMap> &items);
+    QString browserInsert(const QString &tabName, int row, const VariantMapList &items);
+    QString browserChange(const QString &tabName, int row, const VariantMapList &items);
 
     QByteArray browserItemData(const QString &tabName, int arg1, const QString &arg2);
     QVariantMap browserItemData(const QString &tabName, int arg1);
@@ -177,8 +193,8 @@ public slots:
     QVariantMap selectedItemData(int selectedIndex);
     bool setSelectedItemData(int selectedIndex, const QVariantMap &data);
 
-    QVector<QVariantMap> selectedItemsData();
-    void setSelectedItemsData(const QVector<QVariantMap> &dataList);
+    VariantMapList selectedItemsData();
+    void setSelectedItemsData(const VariantMapList &dataList);
 
     int createSelection(const QString &tabName);
     int selectionCopy(int id);
@@ -229,7 +245,7 @@ public slots:
 
     QStringList screenNames();
 
-    Qt::KeyboardModifiers queryKeyboardModifiers();
+    KeyboardModifierList queryKeyboardModifiers();
     QPoint pointerPosition();
     void setPointerPosition(int x, int y);
 
