@@ -10,8 +10,13 @@ set -xeuo pipefail
     git commit -m "Initial"
 )
 
-# workaround for symlink issue
-rm -rf /usr/local/bin/2to3
+# workaround for symlink issues
+rm -rf \
+    /usr/local/bin/2to3* \
+    /usr/local/bin/idle3* \
+    /usr/local/bin/pydoc3* \
+    /usr/local/bin/python3* \
+    /usr/local/bin/python3-config*
 
 # Install Homebrew: https://brew.sh/
 /bin/bash -c "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/master/install.sh)"
